powered by
Authenticates the user to fetch data from the respective Jira installation.
jira.login(jira.env = NULL, jira.user = NULL, jira.pwd = NULL, jira.val = 0, logs = FALSE)
Web address of 'Jira' environment (e.g. https://issues.apache.org/jira)
Jira User Name
Jira Password
0/1 how should the list values be returned in the query results
debug logs required on not (Default = FALSE)
The function authenticates the user into Jira installation and caches the Jira credentials.
# NOT RUN { jira.login(jira.env="https://issues.apache.org/jira", jira.user="jiraTestUser", jira.pwd="jiraTestPwd") # }
Run the code above in your browser using DataLab