jira_sprint_days: jira_sprint_days

Description Usage Arguments See Also

View source: R/jira_sprint_days.R

Description

Calculate the average number of days per ticket in each status in the sprint

Usage

1

Arguments

x

The sprint dataframe

cols

A string or vector of strings of named columns to group by - 'change_from' is automatically part of the grouping, so leave it out

See Also

jira_sprint_review which creates the underlying data set


neugelb/njira documentation built on Sept. 2, 2020, 7:02 p.m.