jira_tickets_day: jira_tickets_day

Description Usage Arguments See Also

View source: R/jira_tickets_day.R

Description

Create a time series for ticket creation and resolution

Usage

1

Arguments

df

The data frame created in jira_issues

max_results

How many results you want to get back

See Also

jira_extract which is a key component of this function


neugelb/njira documentation built on Sept. 2, 2020, 7:02 p.m.