The function parses the groupby clause and returns the modified string as per the specified mode.
rk.groupby(groupby = NULL, mode = "@")clause following simplified sql syntax.
specifies the parsing logic. The default value '@' returns the groupby clause in perfmeter format. Any other value returns the groupby fields used for aggregation.
The function returns the processed groupby clause.