The function returns the list of tables, fields, and their descriptions.
rk.metadata(table = NULL, fields = NULL, gettabs, getflds,
infofile = NULL)name of the interface tables. If not specified, all the tables of the given interface are returned.
is the list of field names whose details are required. If not specified, all the fields of the specified tables are returned.
is a function that returns the list of all the tables for the given interface.
is a function that returns the list of all the fields for the given table.
is the name of the file containing information about different tables and fields of the given interface.
The function returns the resulting data frame.