rk.query: Data Processing Query
Description
The function applies the given fields, where clause, and group by fields on the specified data frame.
Usage
rk.query(dframe, fields = NULL, where = NULL, groupby = NULL)
Arguments
dframe
data frame to be processed.
where
clause applied on the data.
groupby
used to aggregate the fields.
Value
The function returns the resulting data frame.