Description Usage Arguments See Also
View source: R/jira_sprint_days.R
Calculate the average number of days per ticket in each status in the sprint
1 | jira_sprint_days(x, cols)
|
x |
The sprint dataframe |
cols |
A string or vector of strings of named columns to group by - 'change_from' is automatically part of the grouping, so leave it out |
jira_sprint_review which creates the underlying data set
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.