Description Usage Arguments See Also
View source: R/jira_tickets_day.R
Create a time series for ticket creation and resolution
1 |
df |
The data frame created in |
max_results |
How many results you want to get back |
jira_extract which is a key component of this function
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.